@@ -1,7 +1,8 @@
+-- TODO move to pgtap
 
-DROP TABLE edge_table;
-DROP TABLE edge_table_vertices_pgr;
-CREATE TABLE edge_table (
+DROP TABLE edges;
+DROP TABLE vertices;
+CREATE TABLE edges (
     id integer,
     source integer,
     target integer,
@@ -11,7 +12,7 @@ CREATE TABLE edge_table (
 
 
 
-INSERT INTO edge_table (id, source, target, cost, the_geom) VALUES
+INSERT INTO edges (id, source, target, cost, the_geom) VALUES
 (664, 75242, 13078, 1, '01050000000100000001020000000500000006BB5C440B595D413FE94F59BAA125410134DD6412595D41A025BB1FD6A125413849F7A815595D41640C555DEBA12541336449FE18595D41899CBB7916A225418F8280C419595D412B03161742A22541'),
 (700, 41613, 6810, 1, '010500000001000000010200000004000000E44CC814E05C5D41C9DAE107B8AB254139C51DD7E25C5D41B9326524F9AB25415226091BE65C5D415F2F44630EAC25414C05189BEA5C5D411C439CCD14AC2541'),
 (716, 45339, 41613, 1, '01050000000100000001020000000500000064F3864EEB5C5D410656760257AB254164869F7DE75C5D41AB83AD0C5FAB25414810CFBDE35C5D4189D7B9F57CAB2541EA0FD53FE15C5D41DA0C855493AB2541E44CC814E05C5D41C9DAE107B8AB2541'),
@@ -316,13 +317,13 @@ INSERT INTO edge_table (id, source, target, cost, the_geom) VALUES
 (170151, 11736, 70733, 1, '0105000000010000000102000000050000001448CDD103595D4139CEAC9C859B254144BF53FFF9585D4192F23763DE9C2541B3737717F5585D41E289758BF49D254130783A6DF6585D4183DA6569D69E2541D3473EF6F9585D4197B02122439F2541');
 
 
-WITH a AS (SELECT source FROM edge_table UNION select target FROM edge_table)
-SELECT source AS id INTO edge_table_vertices_pgr FROM a;
+WITH a AS (SELECT source FROM edges UNION select target FROM edge_table)
+SELECT source AS id INTO vertices FROM a;
 
 DROP TABLE IF EXISTS result2;
 SELECT  * INTO result2 FROM pgr_lineGraphFull(
     $$SELECT id, source, target, cost
-    FROM edge_table$$
+    FROM edges$$
 );
 SELECT count(*) FROM result2;
 
@@ -340,7 +341,7 @@ SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NOT NULL;
 SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NULL;
 
 UPDATE result2_vertices_pgr AS r SET original_id = v.id
-FROM edge_table_vertices_pgr AS v WHERE v.id = r.id;
+FROM vertices AS v WHERE v.id = r.id;
 
 SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NOT NULL;
 SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NULL;
@@ -367,7 +368,7 @@ SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NULL;
 
 WITH a AS (SELECT id FROM result2_vertices_pgr WHERE original_id IS NULL),
 b AS (SELECT source,edge FROM result2 WHERE source IN (SELECT id FROM a)),
-c AS (SELECT id,source FROM edge_table WHERE id IN (SELECT edge FROM b))
+c AS (SELECT id,source FROM edges WHERE id IN (SELECT edge FROM b))
 UPDATE result2_vertices_pgr AS d SET original_id = (SELECT source FROM c WHERE c.id = (SELECT edge FROM b WHERE b.source = d.id)) WHERE id IN (SELECT id FROM a);
 
 SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NOT NULL;
@@ -375,7 +376,7 @@ SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NULL;
 
 WITH a AS (SELECT id FROM result2_vertices_pgr WHERE original_id IS NULL),
 b AS (SELECT target,edge FROM result2 WHERE target IN (SELECT id FROM a)),
-c AS (SELECT id,target FROM edge_table WHERE id IN (SELECT edge FROM b))
+c AS (SELECT id,target FROM edges WHERE id IN (SELECT edge FROM b))
 UPDATE result2_vertices_pgr AS d SET original_id = (SELECT target FROM c WHERE c.id = (SELECT edge FROM b WHERE b.target = d.id)) WHERE id IN (SELECT id FROM a);
 
 SELECT count(*) FROM result2_vertices_pgr WHERE original_id IS NOT NULL;
