@@ -1,7 +1,6 @@
-
 /* -- q1 */
 SELECT edge, cost FROM pgr_prim(
-    'SELECT id, source, target, cost, reverse_cost FROM edge_table WHERE id < 14'
+  'SELECT id, source, target, cost, reverse_cost
+  FROM edges WHERE id < 14'
 ) ORDER BY edge;
-
 /* -- q2 */
