@@ -24,15 +24,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
     SELECT * FROM pgr_trspViaVertices(
-        'SELECT id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost FROM edge_table',
-        ARRAY[2, 7, 11]::INTEGER[],     -- array of vids
+        'SELECT id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost FROM edges',
+        ARRAY[6, 1, 12]::INTEGER[],     -- array of vids
         true,  -- directed graph?
         true,  -- has_reverse_cost?
         -- include the turn restrictions
         'SELECT to_cost, target_id::INTEGER, from_edge||coalesce('',''||via_path,'''') AS via_path FROM restrictions');
 
     SELECT * FROM pgr_trspViaEdges(
-        'SELECT id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost FROM edge_table',
+        'SELECT id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost FROM edges',
         ARRAY[4,6,11]::INTEGER[],           -- array of eids
         ARRAY[0.5, 0.5, 0.5]::float8[],     -- array of pcts
         true,  -- directed graph?
@@ -40,7 +40,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
         -- include the turn restrictions
         'SELECT to_cost, target_id::INTEGER, from_edge||coalesce('',''||via_path,'''') AS via_path FROM restrictions');
     SELECT * FROM pgr_trspViaEdges(
-        'SELECT id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost FROM edge_table',
+        'SELECT id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost FROM edges',
         ARRAY[1,11,6]::INTEGER[],           -- array of eids
         ARRAY[0.5, 0.5, 0.5]::float8[],     -- array of pcts
         true,  -- directed graph?
@@ -48,7 +48,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
         -- include the turn restrictions
         'SELECT to_cost, target_id::INTEGER, from_edge||coalesce('',''||via_path,'''') AS via_path FROM restrictions');
     SELECT * FROM pgr_trspViaEdges(
-        'SELECT id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost FROM edge_table',
+        'SELECT id::INTEGER, source::INTEGER, target::INTEGER,cost, reverse_cost FROM edges',
         ARRAY[1,11,6]::INTEGER[],           -- array of eids
         ARRAY[0.5, 0.5, 0.5]::float8[],     -- array of pcts
         true,  -- directed graph?
