@@ -2,6 +2,6 @@
 --------------------------------------------------------------------------------
 --                pgr_version
 --------------------------------------------------------------------------------
-\echo -- q1
+/* -- q1 */
 SELECT version, library FROM pgr_full_version();
-\echo -- q2
+/* -- q2 */
