@@ -1,26 +1,19 @@
 SET extra_float_digits=-3;
-
 /* --q1 */
 SELECT * FROM pgr_withPointsKSP(
-    'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
+    'SELECT id, source, target, cost, reverse_cost FROM edges ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, -2, 2);
 /* --q2 */
 SELECT * FROM pgr_withPointsKSP(
-    'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
-    'SELECT pid, edge_id, fraction, side from pointsOfInterest',
-    -1, 6, 2, details := true);
-/* --q3 */
-SELECT * FROM pgr_withPointsKSP(
-    'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
+    'SELECT id, source, target, cost, reverse_cost FROM edges ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, -2, 2,
     driving_side := 'l', details := true);
-/* --q4 */
+/* --q3 */
 SELECT * FROM pgr_withPointsKSP(
-    'SELECT id, source, target, cost, reverse_cost FROM edge_table ORDER BY id',
+    'SELECT id, source, target, cost, reverse_cost FROM edges ORDER BY id',
     'SELECT pid, edge_id, fraction, side from pointsOfInterest',
     -1, -2, 2,
     heap_paths := true, driving_side := 'r', details := true);
-/* --q5 */
-
+/* --q4 */
