@@ -38,7 +38,7 @@ clean_vids(std::vector<int64_t> vids);
 
 std::vector<MST_rt>
 get_no_edge_graph_result(
-        std::vector<int64_t> vids);
+        const std::vector<int64_t>& vids);
 
 }  // namespace details
 }  // namespace pgrouting
