@@ -40,7 +40,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include "cpp_common/identifier.h"
 #include "vrp/vehicle_node.h"
-#include "c_types/pickDeliver/general_vehicle_orders_t.h"
+using Schedule_rt = struct Schedule_rt;
 
 namespace pgrouting {
 namespace vrp {
@@ -88,7 +88,7 @@ class Vehicle : public Identifier {
       * (twv, cv, fleet_size, wait_time, duration)
       */
      typedef std::tuple< int, int, size_t, double, double > Cost;
-     std::vector<General_vehicle_orders_t>
+     std::vector<Schedule_rt>
            get_postgres_result(int vid) const;
 
      Vehicle(const Vehicle &) = default;
@@ -143,7 +143,7 @@ class Vehicle : public Identifier {
       *
       * @returns position where it was inserted
       */
-     POS insert(std::pair<POS, POS> position_limits, const Vehicle_node &node);
+     POS insert(const std::pair<POS, POS>& position_limits, const Vehicle_node &node);
 
 
 
