@@ -85,7 +85,7 @@ Fleet::get_truck(size_t order) {
     msg().log << "Available vehicles: " << m_un_used << "\n";
     msg().log << "NOT Available vehicles: " << m_used << "\n";
 #endif
-    auto idx = m_un_used.front();
+    size_t idx{0};
 
     for (const auto &i : m_un_used) {
         if (m_trucks[i].feasable_orders().has(order)) {
@@ -103,7 +103,7 @@ Fleet::get_truck(size_t order) {
     pgassert(false);
     return m_trucks.back();
 
-    for (auto truck : m_trucks) {
+    for (const auto& truck : m_trucks) {
         if (truck.feasable_orders().has(order)) {
             idx = truck.idx();
             msg().log << "idx" << idx << "size" << m_trucks.size();
@@ -254,7 +254,7 @@ bool
 Fleet::is_fleet_ok() const {
     ENTERING(msg());
     if (!msg().get_error().empty()) return false;
-    for (auto truck : m_trucks) {
+    for (const auto& truck : m_trucks) {
         if (!truck.is_ok()) {
             msg().error << "Illegal values found on vehicle";
             msg().log << "On vehicle " << truck.id()
