@@ -117,12 +117,6 @@ Optimize::inter_swap() {
         }
     }
 
-#if 0
-    while (!p_swaps.empty()) {
-        swapped_f = swap_order() || swapped_f;
-    }
-#endif
-
     msg().log
         << "\n" <<tau("after");
     delete_empty_truck();
@@ -269,133 +263,6 @@ Optimize::swap_worse(Vehicle_pickDeliver &to, Vehicle_pickDeliver &from) {
 }
 
 
-#if 0
-bool
-Optimize::swap_order() {
-#if 0
-    msg().log << "++++++++" << p_swaps;
-#endif
-    while (!p_swaps.empty()) {
-        auto swap_data = p_swaps.top();
-        p_swaps.pop();
-        size_t from_pos = 0;
-        size_t to_pos = 0;
-
-        for (; from_pos < fleet.size()
-                && fleet[from_pos].idx() != swap_data.from_truck.idx()
-                ; ++from_pos) {
-        }
-        pgassert(from_pos < fleet.size());
-        for (; to_pos < fleet.size()
-                && fleet[to_pos].idx() != swap_data.to_truck.idx()
-                ; ++to_pos) {
-        }
-        pgassert(to_pos < fleet.size());
-
-        if (swap_order(
-                fleet[from_pos].orders()[swap_data.from_order], fleet[from_pos],
-                fleet[to_pos].orders()[swap_data.to_order], fleet[to_pos])) {
-            save_if_best();
-#if 0
-            msg().log
-                << "\n Swapping order "
-                << fleet[from_pos].orders()[
-                    swap_data.from_order].pickup().original_id()
-                << " from truck " << fleet[from_pos].id()
-                << " with order "
-                << fleet[to_pos].orders()[
-                    swap_data.to_order].pickup().original_id()
-                << " of truck " <<  fleet[to_pos].id();
-#endif
-#if 0
-            msg().log << "\nswappping after:";
-            msg().log << "\n" <<  fleet[to_pos].tau();
-            msg().log << "\n" << fleet[from_pos].tau();
-#endif
-            return true;
-        }
-    }
-    return false;
-}
-#endif
-
-/*
- * from_truck: position of the truck where the order is
- * to truck: truck to put the order
- */
-bool
-Optimize::swap_order(
-        const Order from_order,
-        Vehicle_pickDeliver &from_truck,
-        const Order to_order,
-        Vehicle_pickDeliver &to_truck) {
-    if (!from_truck.has_order(from_order)
-            || !to_truck.has_order(to_order)) {
-        return false;
-    }
-
-    pgassert(from_truck.has_order(from_order));
-    pgassert(to_truck.has_order(to_order));
-
-    from_truck.erase(from_order);
-    to_truck.erase(to_order);
-
-    /*
-     * insert them in the other truck
-     */
-    if (this->get_kind() == OneDepot) {
-        from_truck.semiLIFO(to_order);
-        to_truck.semiLIFO(from_order);
-    } else {
-        from_truck.insert(to_order);
-        to_truck.insert(from_order);
-    }
-
-    pgassert((from_truck.has_order(to_order) && from_truck.is_feasable()) || !from_truck.has_order(to_order));
-    pgassert((to_truck.has_order(from_order) && to_truck.is_feasable()) || !to_truck.has_order(from_order));
-
-    if (!from_truck.has_order(to_order) || !to_truck.has_order(from_order)) {
-        /*
-         * swap generates a violation: restore trucks
-         */
-        if (from_truck.has_order(to_order)) from_truck.erase(to_order);
-        if (to_truck.has_order(from_order)) to_truck.erase(from_order);
-
-        pgassert(!from_truck.has_order(to_order));
-        pgassert(!from_truck.has_order(from_order));
-        pgassert(!to_truck.has_order(from_order));
-        pgassert(!to_truck.has_order(to_order));
-
-        /*
-         * insert them again in the truck
-         */
-        if (this->get_kind() == OneDepot) {
-            from_truck.semiLIFO(from_order);
-            to_truck.semiLIFO(to_order);
-        } else {
-            from_truck.insert(from_order);
-            to_truck.insert(to_order);
-        }
-        pgassert((from_truck.has_order(from_order) && from_truck.is_feasable()) || !from_truck.has_order(from_order));
-        pgassert((to_truck.has_order(to_order) && to_truck.is_feasable()) || !to_truck.has_order(to_order));
-
-        return false;
-    }
-
-    pgassert(from_truck.has_order(to_order));
-    pgassert(to_truck.has_order(from_order));
-    return true;
-}
-
-void
-Optimize::sort_by_id() {
-    std::sort(fleet.begin(), fleet.end(), []
-            (const Vehicle_pickDeliver &lhs, const Vehicle_pickDeliver &rhs)
-            -> bool {
-            return lhs.orders_in_vehicle().size()
-            > rhs.orders_in_vehicle().size();
-            });
-}
 
 void
 Optimize::sort_by_size() {
@@ -428,83 +295,6 @@ Optimize::delete_empty_truck() {
     save_if_best();
 }
 
-#if 0
-void
-Optimize::move_duration_based() {
-    auto local_limit(fleet.size());
-    size_t i(0);
-
-    sort_by_duration();
-    msg().log << tau("\nmove duration based");
-    while (move_reduce_cost() && (++i < local_limit)) { }
-    delete_empty_truck();
-
-    i = 0;
-    sort_by_duration();
-    std::reverse(fleet.begin(), fleet.end());
-    msg().log << tau("\nmove duration based");
-    while (move_reduce_cost() && (++i < local_limit)) { }
-    sort_by_duration();
-    delete_empty_truck();
-    this->fleet = best_solution.fleet;
-}
-
-
-void
-Optimize::move_wait_time_based() {
-    this->fleet = best_solution.fleet;
-
-    auto local_limit(fleet.size());
-    size_t i(0);
-
-    sort_for_move();
-    msg().log << tau("\nmove wait_time based");
-    while (move_reduce_cost() && (++i < local_limit)) { }
-    delete_empty_truck();
-
-    i = 0;
-    sort_for_move();
-    std::reverse(fleet.begin(), fleet.end());
-    msg().log << tau("\nmove wait_time based");
-    while (move_reduce_cost() && (++i < local_limit)) { }
-    sort_by_duration();
-    delete_empty_truck();
-    this->fleet = best_solution.fleet;
-}
-#endif
-
-#if 0
-/*
- * On the current order of the fleet
- * T1 .......Tn-1  Tn Tn+1...... Tsize
- * Tn tries to move orders to trucks
- *      T1 .... Tn-1
- * So that it gets space for the orders given by
- *      Tn+1 .... Tsize
- * On the first move possible it returns
- *
- * When a truck is emptied, then it removes the truck from the fleet
- *
- * Returns true: when a move was possible
- * Returns false: when a move was not possible
- */
-
-
-bool
-Optimize::move_reduce_cost() {
-    if (fleet.size() < 2) return false;
-    bool moved = false;
-
-    size_t from_pos(fleet.size() - 1);
-    while (from_pos > 1) {
-        for (size_t to_pos = 0; to_pos < from_pos; ++to_pos) {
-            moved = move_reduce_cost(from_pos, to_pos) || moved;
-        }
-        --from_pos;
-    }
-    return moved;
-}
-#endif
 
 /*
  * from_truck trying to make from_truck's duration smaller
@@ -601,7 +391,7 @@ Optimize::move_reduce_cost(
  */
 bool
 Optimize::move_order(
-        Order order,
+        const Order& order,
         Vehicle_pickDeliver &from_truck,
         Vehicle_pickDeliver &to_truck) {
     pgassert(from_truck.has_order(order));
@@ -643,20 +433,6 @@ Optimize::move_order(
     return false;
 }
 
-void
-Optimize::sort_for_move() {
-    std::sort(fleet.begin(), fleet.end(), []
-            (const Vehicle_pickDeliver &lhs, const Vehicle_pickDeliver &rhs)
-            -> bool {
-            return lhs.total_wait_time() > rhs.total_wait_time();
-            });
-
-    std::stable_sort(fleet.begin(), fleet.end(), []
-            (const Vehicle_pickDeliver &lhs, const Vehicle_pickDeliver &rhs)
-            -> bool {
-            return lhs.orders_size() > rhs.orders_size();
-            });
-}
 
 
 /*
