@@ -43,7 +43,7 @@ clean_vids(std::vector<int64_t> vids) {
 
 std::vector<MST_rt>
 get_no_edge_graph_result(
-        std::vector<int64_t> vids) {
+        const std::vector<int64_t>& vids) {
     std::vector<MST_rt> results;
     if (vids.empty()) return results;
     for (auto const root : clean_vids(vids)) {
