@@ -7,7 +7,7 @@
 # ------------------------------------------------------------------------------
 
 # For all the chapter files
-find locale/en -type f -name '*.po' -exec sh -c '
+find locale -type f -name '*.po' -exec sh -c '
     if grep -q "#~" "$1"; then
         perl -pi -0777 -e "s/#~.*//s" "$1"
         git add "$1"
